@@ -1,24 +1,26 @@
-( cd usr/share/doc/HTML/hu/kteatime ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kteatime ; ln -sf /usr/share/doc/HTML/hu//common common )
 ( cd usr/share/doc/HTML/hu/amor ; rm -rf common )
 ( cd usr/share/doc/HTML/hu/amor ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/telnet ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/telnet ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/sftp ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/sftp ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/mailto ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/mailto ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/nfs ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/nfs ; ln -sf /usr/share/doc/HTML/hu//common common )
 ( cd usr/share/doc/HTML/hu/kioslave/file ; rm -rf common )
 ( cd usr/share/doc/HTML/hu/kioslave/file ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/rlogin ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/tar ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/tar ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/mailto ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/mailto ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/sftp ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/sftp ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/telnet ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/telnet ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/news ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/news ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/nfs ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/nfs ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kioslave/ldap ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kioslave/ldap ; ln -sf /usr/share/doc/HTML/hu//common common )
 ( cd usr/share/doc/HTML/hu/kioslave/nntp ; rm -rf common )
 ( cd usr/share/doc/HTML/hu/kioslave/nntp ; ln -sf /usr/share/doc/HTML/hu//common common )
 ( cd usr/share/doc/HTML/hu/kioslave/ftp ; rm -rf common )
 ( cd usr/share/doc/HTML/hu/kioslave/ftp ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/tar ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/tar ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/rlogin ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/rlogin ; ln -sf /usr/share/doc/HTML/hu//common common )
-( cd usr/share/doc/HTML/hu/kioslave/ldap ; rm -rf common )
-( cd usr/share/doc/HTML/hu/kioslave/ldap ; ln -sf /usr/share/doc/HTML/hu//common common )
+( cd usr/share/doc/HTML/hu/kteatime ; rm -rf common )
+( cd usr/share/doc/HTML/hu/kteatime ; ln -sf /usr/share/doc/HTML/hu//common common )
